{************************************************}
{						 }
{ E! for Windows				 }
{ (c) - MainSoft sarl - 1992,1994		 }
{						 }
{ Sample Extension DLL - version 1.0		 }
{						 }
{ This DLL centers the current Editor window	 }
{ or the Control Center on the screen.		 }
{						 }
{************************************************}

(*
CENTER is an Extension DLL allowing to center either the current Editor
window or the Control Center on the screen.

To use this DLL simply load it from the user menu or add its name to the
list of autoloaded Extension DLLs using the Autoload dialog box from
the User Menu of EW. That's all.

This Extension DLL uses no hook. Since it attaches itself to the User Menu,
you don't need to run it from the User|Execute Extension Menu. Two new
options, "Center Editor Window" and "Center CC", will automatically appear
in the User Menu.

This DLL uses the Menu Dispatching feature. It shows you how multiple
entries can be added from a single Extension DLL to the User Menu.

CENTER is intended to be triggered from the User Menu or attached to a
keystroke. When executed from anywhere else, including from another
Extension DLL, the Execute function will receive a null parameter. In that
case, the function will default to "Center Window".

If you want to attach this User Extension to a keystroke, please use
Routine Id = 1 for "Center Window" and Routine Id = 2 for "Center CC"
(this value can be set from the key assignment dialog box).

Please see explanations about the Menu Dispatching feature in the EW API
documentation distributed to registered users.
*)

{$I compdir.inc}
{$C MOVEABLE PRELOAD DISCARDABLE}

library Ansi2Oem;

uses WinProcs, WinTypes, Win31, EWApImp2;

const
  WinTitle : PChar = 'Center Editor window';
  CCTitle : PChar = 'Center CC';
  WinId = 1;   { Routine Id for "Center Window" command }
  CCId = 2;  { Routine Id for "Center CC" command }

var
  SaveExit    : Pointer;  { Save ExitProc }
  WinEntryId,		  { Entry Id for the "Center Window" menu }
  CCEntryId   : longint;  { Entry Id for the "Center CC" menu }


function EWExecute(RoutineId : word) : integer; export;

var
  H	    : hWnd;
  width,
  height,
  NewPosX,
  NewPosY,
  X, Y	    : integer;
  R	    : TRect;

begin
  if RoutineId = 0 then
    RoutineId := WinId; {-We default to "Center Window"}
  case RoutineId of
    WinId: H := EWGetWindowHandle;
    CCId:  H := FindWindow('EWCC', nil);
  end;
  if H <> 0 then begin
    X := GetSystemMetrics(sm_CXScreen);
    Y := GetSystemMetrics(sm_CYScreen);
    GetWindowRect(H, R);
    width := R.Right - R.left;
    height := R.bottom - R.top;
    NewPosX := (X - width) div 2;
    NewPosY := (Y - height) div 2;
    MoveWindow(H, NewPosX, NewPosY, width, height, true);
    if RoutineId = CCId then
      ShowWindow(H, sw_ShowNormal);
    EWExecute := 0;
  end else
    EWExecute := -1;
end;

procedure LibExit; far;
begin
 {-Remove menu items from the User Menu before unloading}
  EWRemoveMenuEntry(WinEntryId);
  EWRemoveMenuEntry(CCEntryId);
  ExitProc := SaveExit;
end;

exports
  EWExecute	index 1;

begin
  SaveExit := ExitProc;
  ExitProc := @LibExit;
 {-Extension attaches itself to the user Menu}
 { Two commands are made available. Therefore we create two menu entries}
  WinEntryId  := EWAddMenuEntry('center', WinTitle, 0, EWMNU_Extension, WinId);
  CCEntryId := EWAddMenuEntry('center', CCTitle, 0, EWMNU_Extension, CCId);
end.
